/*******************************************************************************
 *
 * Copyright (c) 2016-2026 HYCON Technology, Inc.
 * All rights reserved.
 * HYCON Technology <www.hycontek.com>
 *
 * HYCON reserves the right to amend this code without notice at any time.
 * HYCON assumes no responsibility for any errors appeared in the code,
 * and HYCON disclaims any express or implied warranty, relating to sale
 * and/or use of this code including liability or warranties relating
 * to fitness for a particular purpose, or infringement of any patent,
 * copyright or other intellectual property right.
 *
 * -----------------------------------------------------------------------------
 * File Name    : user_LCD.h
 * IDE tooling  : AndeSight C/C++ IDE, version: 2.0.1 Build ID : 201303201736
 * Device Ver.  : V0.9 crt0.o for HY16F19xx & HY16F18xx MCU.
 * Library Ver. : 1.1
 * MCU Device   : HY16F198B-L100 @3.0V
 * Description  : This file implements the customer's function.
 * Created Date : 2016/05/28
 * Created by   :
 *
 ******************************************************************************/

#ifndef _USER_LCD_H_
#define _USER_LCD_H_

/*----------------------------------------------------------------------------*/
/* Header file include                                                        */
/*----------------------------------------------------------------------------*/
//#include "DrvLCD.h"


/*----------------------------------------------------------------------------*/
/* Global variable definition                                                 */
/*----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------*/
/* Constant value definition                                                  */
/*----------------------------------------------------------------------------*/

//------LCD DIG's seg define--------------------
// 7-segment arragment :
//       a
//     -----
//    |     |
//   f|     |b
//    |  g  |
//     -----
//    |     |
//   e|     |c
//    |  d  |
//     -----  . h

#define seg_a           0x01                    //bit of SEG. a.
#define seg_b           0x02                    //bit of SEG. b.
#define seg_c           0x04                    //bit of SEG. c.
#define seg_d           0x80                    //bit of SEG. d.
#define seg_e           0x40                    //bit of SEG. e.
#define seg_f           0x10                    //bit of SEG. f.
#define seg_g           0x20                    //bit of SEG. g.
#define seg_h           0x08                    //bit of SEG. h.

//------LCD's symbol define---------------------
#define S_Bat1          0x10                    //S1(Bat1)
#define S_Bat2          0x20                    //S2(Bat2)
#define S_Bat3          0x40                    //S3(Bat3)
#define S_Bat4          0x80                    //S4(Bat4)
#define S_Minus         0x10                    //S5(Minus) for LCD3.
#define S_Tare          0x20                    //S6(Tare) for LCD3.
#define S_Zero          0x40                    //S7(Zero) for LCD3.
#define S_m1            0x80                    //S8(m)  for LCD3.
#define S_K             0x01                    //S9 for LCD3.
#define S_M2            0x10                    //S10(M)
#define S11             0x20                    //S11
#define S12             0x40                    //S12
#define S13             0x80                    //S13
#define S_A             0x02                    //S14(A) for LCD3.
#define S_Ohm           0x04                    //S15(Ohm) for LCD3.
#define S_V             0x08                    //S16(V) for LCD3.
#define S_g             0x08                    //S17(g)
#define S18             0x10                    //S18
#define S19             0x20                    //S19
#define S20             0x40                    //S20
#define S21             0x80                    //S21

#define Char_H          seg_b+seg_c+seg_e+seg_f+seg_g
#define Char_Y          seg_b+seg_c+seg_d+seg_f+seg_g
#define Char_c          seg_d+seg_e+seg_g
#define Char_o          seg_c+seg_d+seg_e+seg_g
#define Char_n          seg_c+seg_e+seg_g

#define Char_P          seg_a+seg_b+seg_e+seg_f+seg_g
#define Char_A          seg_a+seg_b+seg_c+seg_e+seg_f+seg_g
#define Char_S          seg_a+seg_c+seg_d+seg_f+seg_g

#define Char_E          seg_a+seg_d+seg_e+seg_f+seg_g
#define Char_r          seg_e+seg_g

#define Char_S          seg_a+seg_c+seg_d+seg_f+seg_g
#define Char_C          seg_a+seg_d+seg_e+seg_f
#define Char_A          seg_a+seg_b+seg_c+seg_e+seg_f+seg_g
#define Char_L          seg_d+seg_e+seg_f
#define Char_Blank      0
#define Char_9          seg_a+seg_b+seg_c+seg_d+seg_f+seg_g

//------LCD RAM define--------------------------
#define LCD_RAM_ADDR_FIRST      0x40850         //
#define LCD_RAM_ADDR_MAP00      0x40850         //for SEG3  & SEG2.
#define LCD_RAM_ADDR_MAP01      0x40854         //for SEG5  & SEG4.
#define LCD_RAM_ADDR_MAP02      0x40858         //for SEG7  & SEG6.
#define LCD_RAM_ADDR_MAP03      0x4085C         //for SEG9  & SEG8.
#define LCD_RAM_ADDR_MAP04      0x40860         //for SEG11 & SEG10.
#define LCD_RAM_ADDR_MAP05      0x40864         //for SEG13 & SEG12.
#define LCD_RAM_ADDR_MAP06      0x40868         //for SEG15 & SEG14.
#define LCD_RAM_ADDR_MAP07      0x4086C         //for SEG17 & SEG16.
#define LCD_RAM_ADDR_MAP08      0x40870         //for SEG19 & SEG18.
#define LCD_RAM_ADDR_MAP09      0x40874         //for SEG21 & SEG20.
#define LCD_RAM_ADDR_MAP10      0x40878         //for SEG23 & SEG22.
#define LCD_RAM_ADDR_MAP11      0x4087C         //for SEG25 & SEG24.
#define LCD_RAM_ADDR_MAP12      0x40880         //for SEG27 & SEG26.
#define LCD_RAM_ADDR_MAP13      0x40884         //for SEG29 & SEG28.
#define LCD_RAM_ADDR_MAP14      0x40888         //for SEG31 & SEG30.
#define LCD_RAM_ADDR_MAP15      0x4088C         //for SEG33 & SEG32.
#define LCD_RAM_ADDR_MAP16      0x40890         //for SEG35 & SEG34.
#define LCD_RAM_ADDR_MAP17      0x40894         //for SEG1  & SEG0.
#define LCD_RAM_ADDR_LAST       0x40894         //

//------MISC define-----------------------------
#define SEG_BUF_SIZE            (36/2)          //total has 36SEG (SEG0~SEG35) for this project.
#define LCD_PANEL1              1               //LCD Panel 1.
#define LCD_PANEL2              2               //LCD Panel 2.
#define LCD_PANEL3              3               //LCD Panel 3.
#define LCD1_BUF_START          4               //Buffer start offset no. for LCD1 DIG0.
#define LCD2_BUF_START          9               //Buffer start offset no. for LCD2 DIG0.
#define LCD3_BUF_START          15              //Buffer start offset no. for LCD3 DIG0.
#define LCD1_DIG_SIZE           4               //4 Dig. for LCD1 display.
#define LCD2_DIG_SIZE           5               //5 Dig. for LCD1 display.
#define LCD3_DIG_SIZE           5               //5 Dig. for LCD1 display.
#define LCD1_POINT_BUF          2               //Point buffer No. for LCD1.
#define LCD2_POINT_BUF          7               //Point buffer No. for LCD2.
#define LCD3_POINT_BUF          12              //Point buffer No. for LCD3.

/*----------------------------------------------------------------------------*/
/* Function prototype declaration                                             */
/*----------------------------------------------------------------------------*/
//extern void LCD_Display_Process(void);

#endif  //_USER_LCD_H_
